#!/bin/sh
#
# Licensed under the GNU GPL.  See LICENSE file for details.
# Copyright 2001 DAX Interactive, LLC.
#

. install.config

PWD=`pwd`

# Build liveice from sources
$GNUTAR xvzf liveice.tar.gz
cd liveice
./configure
make

# Install liveice (default install is in /usr/local/icecast)
cp ../mkdirs .
make install
cd ..
rm -rf liveice

# create the install dir
rm -rf $INSTALLDIR
rm -f /usr/local/bin/opendj
./mkdirs $INSTALLDIR

# copy the jar files over
cp opendj_client.jar $INSTALLDIR

# create the startup script
echo "#!/bin/sh" > $INSTALLDIR/opendj
echo "JAVA=$JAVA" >> $INSTALLDIR/opendj
echo "CLIENT_CLASS=org.opendj.client.Main" >> $INSTALLDIR/opendj
echo "CLASSPATH=$RTJAR:$INSTALLDIR/jrev.jar:$INSTALLDIR/opendj_client.jar" >> $INSTALLDIR/opendj
echo "PROP_FILE=$INSTALLDIR/opendj.properties" >> $INSTALLDIR/opendj
echo "" >> $INSTALLDIR/opendj
echo "\$JAVA -classpath \$CLASSPATH -Djava.compiler=NONE -Dopendj.props=\$PROP_FILE \$CLIENT_CLASS 1> $INSTALLDIR/opendj.out.log 2> $INSTALLDIR/opendj.err.log" >> $INSTALLDIR/opendj
echo "" >> $INSTALLDIR/opendj

# create the config file
echo "# OPENdj server IP and port" >> $INSTALLDIR/opendj.properties
echo "server.host=$SERVER" >> $INSTALLDIR/opendj.properties
echo "server.port=$PORT" >> $INSTALLDIR/opendj.properties
echo "" >> $INSTALLDIR/opendj.properties
echo "# The encoder to use - this will determine which " >> $INSTALLDIR/opendj.properties
echo "# other properties are required (see below)" >> $INSTALLDIR/opendj.properties
echo "encoder.class=org.opendj.client.unix.EncoderImpl" >> $INSTALLDIR/opendj.properties
echo "" >> $INSTALLDIR/opendj.properties
echo "# This is the script that starts liveice." >> $INSTALLDIR/opendj.properties
echo "liveice.start.script=$INSTALLDIR/liveice.start.sh" >> $INSTALLDIR/opendj.properties
echo "" >> $INSTALLDIR/opendj.properties
echo "# This is the script that stops liveice." >> $INSTALLDIR/opendj.properties
echo "liveice.stop.script=$INSTALLDIR/liveice.stop.sh" >> $INSTALLDIR/opendj.properties
echo "" >> $INSTALLDIR/opendj.properties
echo "# This is the configuration template for liveice." >> $INSTALLDIR/opendj.properties
echo "# Be sure to review it to make sure all the settings are correct." >> $INSTALLDIR/opendj.properties
echo "liveice.config.template=$INSTALLDIR/liveice.cfg.template" >> $INSTALLDIR/opendj.properties
echo "" >> $INSTALLDIR/opendj.properties
echo "# This is where the actual liveice config file will be written" >> $INSTALLDIR/opendj.properties
echo "# just before liveice is started." >> $INSTALLDIR/opendj.properties
echo "liveice.config=/usr/local/icecast/etc/liveice.cfg" >> $INSTALLDIR/opendj.properties
echo "" >> $INSTALLDIR/opendj.properties
echo "# This determines the bitrate to send to the icecast server." >> $INSTALLDIR/opendj.properties
echo "icecast.bitrate.use=$BITRATE" >> $INSTALLDIR/opendj.properties

# Generate the encoder start script
echo "#!$SHELL" >> $INSTALLDIR/liveice.start.sh
echo "cat /dev/null > $INSTALLDIR/liveice.err"
echo "cat /dev/null > $INSTALLDIR/liveice.out"
echo "/usr/local/icecast/bin/liveice 2> $INSTALLDIR/liveice.err 1> $INSTALLDIR/liveice.out" >> $INSTALLDIR/liveice.start.sh

# Generate the encoder stop script
echo "#!$SHELL" >> $INSTALLDIR/liveice.stop.sh
echo "$KILLALL liveice" >> $INSTALLDIR/liveice.stop.sh

# Create the liveice config template
echo "SERVER \$\$SERVER\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "PORT \$\$PORT\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "PASSWORD \$\$PASSWORD\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "USE_LAME3 $LAME" >> $INSTALLDIR/liveice.cfg.template
echo "ENCODER_ARGS -h" >> $INSTALLDIR/liveice.cfg.template
echo "SOUNDCARD" >> $INSTALLDIR/liveice.cfg.template
echo "SOUND_DEVICE $SOUNDDEV" >> $INSTALLDIR/liveice.cfg.template
echo "HALF_DUPLEX" >> $INSTALLDIR/liveice.cfg.template
echo "SAMPLE_RATE 22050" >> $INSTALLDIR/liveice.cfg.template
echo "BITRATE \$\$BITRATE\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "MONO" >> $INSTALLDIR/liveice.cfg.template
echo "ENCODING_QUALITY 30" >> $INSTALLDIR/liveice.cfg.template
echo "X_AUDIOCAST_LOGIN" >> $INSTALLDIR/liveice.cfg.template
echo "MOUNTPOINT \$\$MOUNT\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "NAME \$\$SHOWNAME\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "GENRE \$\$GENRE\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "PUBLIC 0" >> $INSTALLDIR/liveice.cfg.template
echo "URL \$\$URL\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "PASSWORD \$\$PASSWORD\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "DESCRIPTION \$\$SHOWNAME\$\$" >> $INSTALLDIR/liveice.cfg.template
echo "NO_MIXER" >> $INSTALLDIR/liveice.cfg.template
echo "PLAYLIST playlist" >> $INSTALLDIR/liveice.cfg.template
echo "DECODER_COMMAND mpg123" >> $INSTALLDIR/liveice.cfg.template
echo "UPDATE_DELAY 2" >> $INSTALLDIR/liveice.cfg.template
echo "VERBOSE 0" >> $INSTALLDIR/liveice.cfg.template

# Make sure that liveice.cfg is writeable by the user
chown $USER /usr/local/icecast/etc/liveice.cfg
chmod 700 /usr/local/icecast/etc/liveice.cfg
chown -R $USER $INSTALLDIR
chmod -R 744 $INSTALLDIR

# create a link to the startup script in /usr/local/bin
cd /usr/local/bin
ln -s $INSTALLDIR/opendj ./opendj

# Go back to where we started
cd $PWD

echo ""
echo "Installation Complete!"
echo ""
echo "Run $INSTALLDIR/opendj or /usr/local/bin/opendj to start OPENdj"
echo ""
